@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::ARODLAND;
 # ABSTRACT: Use L<Dist::Zilla> like ARODLAND does
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.10.0;
 use Moose;
@@ -47,40 +47,33 @@ sub bundle_config {
   my $version_regexp = $config->{git_version_regexp};
   my $autoversion_major = $config->{autoversion_major};
 
+  my $readme_format = $config->{readme_format} // "pod";
+
   my $compat = $config->{compat} || $VERSION;
 
   my ($tracker, $tracker_mailto, $webpage, $repo_url, $repo_web);
 
-  given ($bugtracker) {
-    when ('github') {
-      $tracker = "http://github.com/$github_user/$dist/issues";
-    }
-    when ('rt') {
-      $tracker = "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
-      $tracker_mailto = "bug-${dist}\@rt.cpan.org";
-    }
-    default {
-      $tracker = $bugtracker;
-    }
+  if ($bugtracker eq 'github') {
+    $tracker = "http://github.com/$github_user/$dist/issues";
+  } elsif ($bugtracker eq 'rt') {
+    $tracker = "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
+    $tracker_mailto = "bug-${dist}\@rt.cpan.org";
+  } else {
+    $tracker = $bugtracker;
   }
 
-  given ($repository_url) {
-    when (not defined) {
-      $repo_web = "http://github.com/$github_user/$dist";
-      $repo_url = "git://github.com/$github_user/$dist.git";
-    }
-    default {
-      $repo_web = $repository_web;
-      $repo_url = $repository_url;
-    }
+  if (defined $repository_url) {
+    $repo_web = $repository_web;
+    $repo_url = $repository_url;
+  } else {
+    $repo_web = "http://github.com/$github_user/$dist";
+    $repo_url = "git://github.com/$github_user/$dist.git";
   }
 
-  given ($homepage) {
-    when (not defined) {
-      $webpage = "http://metacpan.org/release/$dist";
-    } default {
-      $webpage = $homepage;
-    }
+  if (defined $homepage) {
+    $webpage = $homepage;
+  } else {
+    $webpage = "http://metacpan.org/release/$dist";
   }
 
   my @plugins = Dist::Zilla::PluginBundle::Basic->bundle_config({
@@ -149,6 +142,7 @@ sub bundle_config {
       GatherDir => {
         exclude_filename => [
           'README',
+          'README.pod',
           'Makefile.PL',
           'Build.PL',
           'META.json'
@@ -156,10 +150,16 @@ sub bundle_config {
       }
     ],
     [
-      ReadmeAnyFromPod => { 
-        type => 'text',
-        filename => 'README',
+      ReadmeAnyFromPod => {
         location => 'root',
+        ($readme_format eq 'pod'
+          ? (type => 'pod', filename => 'README.pod')
+          : ()
+        ),
+        ($readme_format eq 'text'
+          ? (type => 'text', filename => 'README')
+          : ()
+        ),
       }
     ],
     [
@@ -191,32 +191,30 @@ sub bundle_config {
 #    [ CheckChangesHasContent => { } ],
   );
 
-  given ($nextversion) {
-    when ('git') {
-      push @plugins, [ "$section->{name}/Git::NextVersion", "Dist::Zilla::Plugin::Git::NextVersion",
-        {
-          first_version => '0.01',
-          ( $version_regexp
-            ? (version_regexp => $version_regexp)
-            : (version_regexp => '^(\d.*)$')
-          ),
-        }
-      ];
-    } when ('autoversion') {
-      push @plugins, [ "$section->{name}/AutoVersion", "Dist::Zilla::Plugin::AutoVersion",
-        { 
-          ( $autoversion_major
-            ? (major => $autoversion_major)
-            : (major => 0)
-          ),
-        }
-      ];
-    } when ('manual') {
-      # Manual versioning
-    } default {
-      die "Unknown 'nextversion'\n";
-    }
-  };
+  if ($nextversion eq 'git') {
+    push @plugins, [ "$section->{name}/Git::NextVersion", "Dist::Zilla::Plugin::Git::NextVersion",
+      {
+        first_version => '0.01',
+        ( $version_regexp
+          ? (version_regexp => $version_regexp)
+          : (version_regexp => '^(\d.*)$')
+        ),
+      }
+    ];
+  } elsif ($nextversion eq 'autoversion') {
+    push @plugins, [ "$section->{name}/AutoVersion", "Dist::Zilla::Plugin::AutoVersion",
+      {
+        ( $autoversion_major
+          ? (major => $autoversion_major)
+          : (major => 0)
+        ),
+      }
+    ];
+  } elsif ($nextversion eq 'manual') {
+    # Manual versioning
+  } else {
+    die "Unknown 'nextversion'\n";
+  }
 
   push @plugins, Dist::Zilla::PluginBundle::Git->bundle_config({
       name    => "$section->{name}/\@Git",
@@ -226,7 +224,7 @@ sub bundle_config {
           ? (tag_message => $tag_message)
           : ()
         ),
-        allow_dirty => ['dist.ini', 'README', 'Changes'],
+        allow_dirty => ['dist.ini', 'README', 'README.pod', 'Changes'],
         changelog => 'Changes',
         commit_msg => 'Release v%v%n%n%c',
         push_to => 'origin',
@@ -250,7 +248,7 @@ Dist::Zilla::PluginBundle::ARODLAND - Use L<Dist::Zilla> like ARODLAND does
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
